@@ -1,4 +1,4 @@
-## ID: polymat.R, last updated 2022-07-05, F.Osorio
+## ID: polymat.R, last updated 2022-08-08, F.Osorio
 
 matrix.polynomial <- function(a, coef = rep(1, power + 1), power = length(coef))
 { ## evaluates a real general matrix polynomial using a Horner's scheme
@@ -22,7 +22,7 @@ matrix.polynomial <- function(a, coef = rep(1, power + 1), power = length(coef))
     stop("argument 'coef' is not a numeric vector")
   ncoef <- length(coef)
 
-  if (all(coef == 1) && (power < 0))
+  if (all(coef == 1.0) && (power < 0))
     stop("argument 'power' must be positive")
 
   mat <- matrix(0, nrow = n, ncol = n)
@@ -35,7 +35,7 @@ matrix.polynomial <- function(a, coef = rep(1, power + 1), power = length(coef))
           ncoef = as.integer(ncoef),
           mat = mat,
           ldmat = as.integer(n),
-          info = as.integer(0))
+          info = as.integer(0))[c("mat", "info")]
   if (z$info)
     stop(paste("matrix_polynomial gave error code", z$info))
   z <- z$mat
